@@ -60,14 +60,17 @@ Big - A class for creating Excel files > 7MB.
 
 =head1 SYNOPSIS
 
-
-See the documentation for Spreadsheet::WriteExcel.
+The direct use of this module is deprecated. See below.
 
 
 =head1 DESCRIPTION
 
+The module is a sub-class of Spreadsheet::WriteExcel used for creating Excel files greater than 7MB.
+
+Direct use of this module is deprecated. As of version 2.17 Spreadsheet::WriteExcel can create files larger than 7MB if OLE::Storage_Lite is installed.
+
+This module only exists for backwards compatibility.
 
-This module is used in conjunction with Spreadsheet::WriteExcel.
 
     use Spreadsheet::WriteExcel::Big;
 
@@ -93,7 +96,7 @@ John McNamara jmcnamara@cpan.org
 =head1 COPYRIGHT
 
 
- MM-MMVI, John McNamara.
+ MM-MMVII, John McNamara.
 
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
